@@ -20,8 +20,8 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <iostream.h>
-#include <fstream.h>
+#include <iostream>
+#include <fstream>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -30,6 +30,10 @@
 #include "fileutil.h"
 #include "my_string.h"
 
+using std::cerr;
+using std::endl;
+using std::ifstream;
+
 static void file_error(const char *error, char *file);
 static void internal_error(const char *error);
 
