@@ -20,7 +20,9 @@
 #ifndef _GENFUN_H
 #define _GENFUN_H
 
-#include <iostream.h>
+#include <iostream>
+
+using std::ostream;
 
 extern char *inputFileName ; /* what we're reading  */
 extern ostream* sout ;
