@@ -20,7 +20,7 @@
 #ifndef LINENOGEN_H
 #define LINENOGEN_H
 
-#include "textgen.h"
+#include "decorators.h"
 
 class LineNumberDecorator : public TextDecorator
 {
